# Tap-Tempo

![Screenshot of the GUI](./screenshot.png)

This is a simple Program to tap-in a tempo.  It calculates the time
between to taps in BPM as well as the average BPM of multiple taps.
The GUI is build with tkinter.
